@@ -11,8 +11,8 @@
 #include "settings_advanced.h"
 
 #include <KAboutData>
-#include <KPluginFactory>
 #include <KLocalizedString>
+#include <KPluginFactory>
 
 #include <QVBoxLayout>
 
@@ -24,11 +24,13 @@ KCMAkregatorAdvancedConfig::KCMAkregatorAdvancedConfig(QWidget *parent, const QV
     : KCModule(parent, args)
     , m_widget(new SettingsAdvanced(this))
 {
-    auto *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->addWidget(m_widget);
     KAboutData *about = new KAboutData(QStringLiteral("kcmakradvancedconfig"),
                                        i18n("Advanced Feed Reader Settings"),
-                                       QString(), QString(), KAboutLicense::GPL,
+                                       QString(),
+                                       QString(),
+                                       KAboutLicense::GPL,
                                        i18n("(c), 2004 - 2008 Frank Osterfeld"));
 
     about->addAuthor(i18n("Frank Osterfeld"), QString(), QStringLiteral("osterfeld@kde.org"));
