@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,11 +9,13 @@
 
 #include <KCModule>
 #include <QVariant>
-namespace PimCommon {
+namespace PimCommon
+{
 class ConfigurePluginsWidget;
 }
 
-namespace Akregator {
+namespace Akregator
+{
 class KCMAkregatorPluginsConfig : public KCModule
 {
     Q_OBJECT
@@ -24,6 +26,7 @@ public:
     void defaults() override;
 private Q_SLOTS:
     void slotConfigChanged();
+
 private:
     PimCommon::ConfigurePluginsWidget *mConfigurePluginWidget = nullptr;
 };
