@@ -11,8 +11,8 @@
 
 #include "akregatorinterfaces_export.h"
 
-#include <QObject>
 #include <QHash>
+#include <QObject>
 #include <QString>
 #include <QVariant>
 
@@ -20,7 +20,8 @@ class KXMLGUIClient;
 
 #define AKREGATOR_PLUGIN_INTERFACE_VERSION 4
 
-namespace Akregator {
+namespace Akregator
+{
 class AKREGATORINTERFACES_EXPORT Plugin : public QObject
 {
     Q_OBJECT
@@ -44,6 +45,6 @@ protected:
 private:
     QHash<QString, QString> m_properties;
 };
-} //namespace Akregator
+} // namespace Akregator
 
 #endif // AKREGATOR_PLUGIN_H
