@@ -26,6 +26,7 @@ using namespace Akregator;
 class Q_DECL_HIDDEN ExpireItemsCommand::Private
 {
     ExpireItemsCommand *const q;
+
 public:
     explicit Private(ExpireItemsCommand *qq);
 
@@ -38,7 +39,8 @@ public:
     QSet<KJob *> m_jobs;
 };
 
-ExpireItemsCommand::Private::Private(ExpireItemsCommand *qq) : q(qq)
+ExpireItemsCommand::Private::Private(ExpireItemsCommand *qq)
+    : q(qq)
     , m_feedList()
 {
 }
@@ -46,7 +48,7 @@ ExpireItemsCommand::Private::Private(ExpireItemsCommand *qq) : q(qq)
 void ExpireItemsCommand::Private::addDeleteJobForFeed(Feed *feed)
 {
     Q_ASSERT(feed);
-    auto *job = new ArticleDeleteJob(q);
+    auto job = new ArticleDeleteJob(q);
     connect(job, &ArticleDeleteJob::finished, q, [this](KJob *job) {
         jobFinished(job);
     });
@@ -86,7 +88,8 @@ void ExpireItemsCommand::Private::createDeleteJobs()
     }
 }
 
-ExpireItemsCommand::ExpireItemsCommand(QObject *parent) : Command(parent)
+ExpireItemsCommand::ExpireItemsCommand(QObject *parent)
+    : Command(parent)
     , d(new Private(this))
 {
 }
