@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,20 +11,16 @@
 #include <QHash>
 #include <QIcon>
 class QAction;
-namespace Akregator {
+namespace Akregator
+{
 class StatusSearchLine : public KLineEdit
 {
     Q_OBJECT
 public:
-    enum Status {
-        AllArticles = 0,
-        NewArticles,
-        UnreadArticles,
-        ImportantArticles
-    };
+    enum Status { AllArticles = 0, NewArticles, UnreadArticles, ImportantArticles };
 
     explicit StatusSearchLine(QWidget *parent = nullptr);
-    ~StatusSearchLine();
+    ~StatusSearchLine() override;
 
     void setStatus(StatusSearchLine::Status status);
 
